@@ -2186,15 +2186,6 @@ var _ = Describe("ClusterConfig validation", func() {
 			err := api.ValidateManagedNodeGroup(0, ng)
 			Expect(err).To(MatchError(ContainSubstring("eksctl does not support configuring maxPodsPerNode EKS-managed nodes")))
 		})
-		It("returns an error when setting preBootstrapCommands for self-managed nodegroups", func() {
-			cfg := api.NewClusterConfig()
-			ng := cfg.NewNodeGroup()
-			ng.Name = "node-group"
-			ng.AMI = "ami-1234"
-			ng.AMIFamily = api.NodeImageFamilyAmazonLinux2023
-			ng.PreBootstrapCommands = []string{"echo 'rubarb'"}
-			Expect(api.ValidateNodeGroup(0, ng, cfg)).To(MatchError(ContainSubstring(fmt.Sprintf("preBootstrapCommands is not supported for %s nodegroups", api.NodeImageFamilyAmazonLinux2023))))
-		})
 		It("returns an error when setting overrideBootstrapCommand for self-managed nodegroups", func() {
 			cfg := api.NewClusterConfig()
 			ng := cfg.NewNodeGroup()
@@ -2204,14 +2195,6 @@ var _ = Describe("ClusterConfig validation", func() {
 			ng.OverrideBootstrapCommand = aws.String("echo 'rubarb'")
 			Expect(api.ValidateNodeGroup(0, ng, cfg)).To(MatchError(ContainSubstring(fmt.Sprintf("overrideBootstrapCommand is not supported for %s nodegroups", api.NodeImageFamilyAmazonLinux2023))))
 		})
-		It("returns an error when setting preBootstrapCommands for EKS-managed nodegroups", func() {
-			ng := api.NewManagedNodeGroup()
-			ng.Name = "node-group"
-			ng.AMI = "ami-1234"
-			ng.AMIFamily = api.NodeImageFamilyAmazonLinux2023
-			ng.PreBootstrapCommands = []string{"echo 'rubarb'"}
-			Expect(api.ValidateManagedNodeGroup(0, ng)).To(MatchError(ContainSubstring(fmt.Sprintf("preBootstrapCommands is not supported for %s nodegroups", api.NodeImageFamilyAmazonLinux2023))))
-		})
 		It("returns an error when setting overrideBootstrapCommand for EKS-managed nodegroups", func() {
 			ng := api.NewManagedNodeGroup()
 			ng.Name = "node-group"
